==> aliyun-java-sdk-ecs-4.16.6-sources.jar: com/aliyuncs/ecs/transform/v20140526/DescribeSnapshotMonitorDataResponseUnmarshaller.java <==
/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.aliyuncs.ecs.transform.v20140526;

import java.util.ArrayList;
import java.util.List;

import com.aliyuncs.ecs.model.v20140526.DescribeSnapshotMonitorDataResponse;
import com.aliyuncs.ecs.model.v20140526.DescribeSnapshotMonitorDataResponse.DataPoint;
import com.aliyuncs.transform.UnmarshallerContext;


public class DescribeSnapshotMonitorDataResponseUnmarshaller {

	public static DescribeSnapshotMonitorDataResponse unmarshall(DescribeSnapshotMonitorDataResponse describeSnapshotMonitorDataResponse, UnmarshallerContext context) {
		
		describeSnapshotMonitorDataResponse.setRequestId(context.stringValue("DescribeSnapshotMonitorDataResponse.RequestId"));

		List<DataPoint> monitorData = new ArrayList<DataPoint>();
		for (int i = 0; i < context.lengthValue("DescribeSnapshotMonitorDataResponse.MonitorData.Length"); i++) {
			DataPoint dataPoint = new DataPoint();
			dataPoint.setTimeStamp(context.stringValue("DescribeSnapshotMonitorDataResponse.MonitorData["+ i +"].TimeStamp"));
			dataPoint.setSize(context.longValue("DescribeSnapshotMonitorDataResponse.MonitorData["+ i +"].Size"));

			monitorData.add(dataPoint);
		}
		describeSnapshotMonitorDataResponse.setMonitorData(monitorData);
	 
	 	return describeSnapshotMonitorDataResponse;
	}
}

==> aliyun-java-sdk-ecs-4.20.0-sources.jar: com/aliyuncs/ecs/transform/v20140526/DescribeSnapshotMonitorDataResponseUnmarshaller.java <==
/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.aliyuncs.ecs.transform.v20140526;

import java.util.ArrayList;
import java.util.List;

import com.aliyuncs.ecs.model.v20140526.DescribeSnapshotMonitorDataResponse;
import com.aliyuncs.ecs.model.v20140526.DescribeSnapshotMonitorDataResponse.DataPoint;
import com.aliyuncs.transform.UnmarshallerContext;


public class DescribeSnapshotMonitorDataResponseUnmarshaller {

	public static DescribeSnapshotMonitorDataResponse unmarshall(DescribeSnapshotMonitorDataResponse describeSnapshotMonitorDataResponse, UnmarshallerContext _ctx) {
		
		describeSnapshotMonitorDataResponse.setRequestId(_ctx.stringValue("DescribeSnapshotMonitorDataResponse.RequestId"));

		List<DataPoint> monitorData = new ArrayList<DataPoint>();
		for (int i = 0; i < _ctx.lengthValue("DescribeSnapshotMonitorDataResponse.MonitorData.Length"); i++) {
			DataPoint dataPoint = new DataPoint();
			dataPoint.setTimeStamp(_ctx.stringValue("DescribeSnapshotMonitorDataResponse.MonitorData["+ i +"].TimeStamp"));
			dataPoint.setSize(_ctx.longValue("DescribeSnapshotMonitorDataResponse.MonitorData["+ i +"].Size"));

			monitorData.add(dataPoint);
		}
		describeSnapshotMonitorDataResponse.setMonitorData(monitorData);
	 
	 	return describeSnapshotMonitorDataResponse;
	}
}
